@@ -67,6 +67,10 @@ def test_buttongroup():
 def test_calendarwiget():
     widget = widgets.CalendarWidget()
     assert widget.get_date() == widget.get_value()
+    widget.set_selection_mode("single")
+    assert widget.get_selection_mode() == "single"
+    with pytest.raises(ValueError):
+        widget.set_selection_mode("test")
     with open("data.pkl", "wb") as jar:
         pickle.dump(widget, jar)
     with open("data.pkl", "rb") as jar:
@@ -236,7 +240,10 @@ def test_filedialog():
     with pytest.raises(ValueError):
         dlg.set_accept_mode("bla")
     dlg.set_accept_mode("save")
-    dlg.set_filter(dict(a=[".csv"]))
+    dlg.set_extension_filter(dict(a=[".csv"]))
+    dlg.set_filter("all_dirs")
+    with pytest.raises(ValueError):
+        dlg.set_filter("test")
     dlg.selected_file()
     dlg.selected_files()
     with open("data.pkl", "wb") as jar:
@@ -327,6 +334,8 @@ def test_headerview():
     table.setHorizontalHeader(header)
     header.resize_mode("interactive")
     header.resize_mode("interactive", col=0)
+    with pytest.raises(ValueError):
+        header.resize_mode("test")
     header.resize_sections("interactive")
     header.set_contextmenu_policy("custom")
     with pytest.raises(ValueError):
@@ -334,8 +343,10 @@ def test_headerview():
     assert header.get_contextmenu_policy() == "custom"
     header.set_custom_menu(test)
     header.set_sizes([100])
-    label = header.section_labels()
-    print(label)
+    assert header.section_labels() == ['Name', 'Size', 'Type', 'Date Modified']
+    header.save_state()
+    header.load_state()
+    header.change_section_vis(0, True)
 
 
 def test_keysequenceedit():
@@ -386,6 +397,7 @@ def test_lineedit():
 
 def test_listview():
     widget = widgets.ListView()
+    widget.set_selection_mode(None)
     widget.set_selection_mode("single")
     widget.toggle_select_all()
     widget.set_selection_mode("multi")
@@ -729,6 +741,8 @@ def test_textbrowser():
         pickle.dump(widget, jar)
     with open("data.pkl", "rb") as jar:
         widget = pickle.load(jar)
+    widget.set_markdown("test")
+    widget.set_rst("test")
 
 
 def test_textedit():
@@ -826,6 +840,7 @@ def test_tableview():
     widget.set_vertical_scrollbar_policy("always_on")
     widget.set_horizontal_scrollbar_width(12)
     widget.set_vertical_scrollbar_width(12)
+    widget.set_edit_triggers(None)
     widget.set_edit_triggers("edit_key")
     with pytest.raises(ValueError):
         widget.set_edit_triggers("test")
